package example.controller;

import example.model.Computer;
import example.service.IComputerService;
import example.service.impl.ComputerServiceImpl;

import javax.servlet.ServletException;
import javax.servlet.annotation.WebServlet;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.sql.SQLException;
import java.util.List;
import java.util.Map;

@WebServlet(urlPatterns = {"/computer"})
public class ComputerServlet extends HttpServlet {

    IComputerService computerService = new ComputerServiceImpl();

    @Override
    protected void doGet(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
        String action = req.getParameter("action");
        switch (action) {
            case "list":
                try {
                    listServlet(req, resp);
                } catch (SQLException e) {
                    throw new RuntimeException(e);
                }
                break;
            case "delete":
                deleteComputer(req, resp);
                break;
            case "add":
                addComputer(req, resp);
                break;
            case "edit":
                editComputer(req, resp);
                break;
        }
    }

    private void editComputer(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
        String id = req.getParameter("id");
        Computer computer = computerService.getComputer(id);
        req.setAttribute("computer", computer);
        req.getRequestDispatcher("editComputer.jsp").forward(req, resp);
    }

    private void addComputer(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
        req.getRequestDispatcher("addComputer.jsp").forward(req, resp);
    }

    private void deleteComputer(HttpServletRequest req, HttpServletResponse resp) {
        String id = req.getParameter("id");
        try {
            computerService.deleteComputer(id);
            resp.sendRedirect("/computer?action=list");
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
    }

    private void listServlet(HttpServletRequest req, HttpServletResponse resp) throws SQLException, ServletException, IOException {
        int page = 1;
        int pageSize = 5; // 每页显示的条数

        // 获取页码参数
        String pageParam = req.getParameter("page");
        if (pageParam != null) {
            page = Integer.parseInt(pageParam);
        }

        // 获取分页数据
        Map<String, Object> data = computerService.listComputersWithPagination(page, pageSize);

        req.setAttribute("computers", data.get("computers"));
        req.setAttribute("totalPages", data.get("totalPages"));
        req.setAttribute("currentPage", data.get("currentPage"));

        req.getRequestDispatcher("computerList.jsp").forward(req, resp);
    }


    @Override
    protected void doPost(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
        String action = req.getParameter("action");
        switch (action) {
            case "add":
                savaComputer(req, resp);
                break;
            case "edit":
                UpdateComputer(req, resp);
                break;
        }
    }

    private void UpdateComputer(HttpServletRequest req, HttpServletResponse resp) throws UnsupportedEncodingException {
        String id = req.getParameter("id");
        String name = req.getParameter("name");
        String price = req.getParameter("price");
        String stock = req.getParameter("stock");
        computerService.updateComputer(id,name,Double.parseDouble(price),Integer.parseInt(stock));
        try {
            resp.sendRedirect("/computer?action=list");
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
    }

    void savaComputer(HttpServletRequest req, HttpServletResponse resp) throws IOException {
        String name = req.getParameter("name");
        String price = req.getParameter("price");
        String stock = req.getParameter("stock");
        computerService.addComputer(name,Double.parseDouble(price),Integer.parseInt(stock));
        try {
            resp.sendRedirect("/computer?action=list");
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
    }
}
