package example.filter;

import javax.servlet.Filter;
import javax.servlet.FilterChain;
import javax.servlet.FilterConfig;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import javax.servlet.annotation.WebFilter;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;
import java.io.IOException;

@WebFilter("/*") // 拦截所有请求路径
public class LoginFilter implements Filter {
    @Override
    public void init(FilterConfig filterConfig) throws ServletException {
        // 初始化操作，可以在这里获取过滤器的初始化参数等
    }
    @Override
    public void doFilter(ServletRequest servletRequest, ServletResponse servletResponse, FilterChain filterChain) throws IOException, ServletException {
        HttpServletRequest request = (HttpServletRequest) servletRequest;
        HttpServletResponse response = (HttpServletResponse) servletResponse;
        HttpSession session = request.getSession(false);
        String requestURI = request.getRequestURI();
        request.setCharacterEncoding("UTF-8");
        try {
            if (requestURI.contains("login.jsp") || requestURI.contains("login") || requestURI.contains("/")) {
                filterChain.doFilter(request, response);
            } else {
                if (session!= null && session.getAttribute("user")!= null) {
                    // 用户已登录，放行请求
                    filterChain.doFilter(request, response);
                } else {
                    // 用户未登录，重定向到登录页面
                    response.sendRedirect("login.jsp");
                }
            }
        }catch (ServletException | IOException | RuntimeException e) {
            // 处理异常，例如重定向到错误页面或者返回错误信息
            response.sendRedirect("/login");
        }
    }
    @Override
    public void destroy() {
        // 销毁资源，例如关闭数据库连接等（如果在过滤器中有相关资源的话）
    }
}